Skip to contents

Supports stacking ggplot2 layers, lists of layers, scales, and themes onto a ggchord plot using the + operator.

Usage

# S3 method for class 'ggchord'
e1 + e2

Arguments

e1

A ggchord object

e2

A ggplot2 layer, a list of layers, a scale, or a theme

Value

A ggchord object