Coerce a validation result to a flat data.frame
Source:R/validate.R
as.data.frame.ggchord_validation.RdCombines the errors and warnings tables into a single
data.frame and adds a severity column, which is convenient for
filtering, exporting or printing the full report programmatically.
Usage
# S3 method for class 'ggchord_validation'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)