Contains core functions for integrating graphic elements and generating the final ggplot2 object.
Integrates all graphic elements to generate the final chord plot
chordPlotFunc(
allRibbon,
ribbon_alpha,
ribbon_color_scheme,
ribbon_colors,
show_legend,
gene_polys,
gene_pal,
gene_color_scheme,
final_gene_order,
seqArcs,
gene_arrows,
gene_label_show,
gene_label_size,
show_axis,
axisLines,
axisTicks,
axisLabelOrientation,
seq_colors,
seq_labels,
seqs,
extremes,
panel_margin,
title
)ggplot2 object
Ribbon data (data.frame)
Ribbon transparency
Ribbon color scheme
Ribbon color parameters
Whether to display the legend
Gene arrow polygon data
Gene color vector
Gene color scheme
Order of genes in the legend
Sequence arc data
Gene label data
Whether to display gene labels
Font size of gene labels
Whether to display axes
Axis line data
Tick mark data
Orientation of axis labels
Sequence color vector
Sequence labels
List of sequence IDs
Plot extrema (min/max coordinates)
Panel margins
Plot title