Skip to contents

A lightweight Coord. It creates placeholder coordinates in ggchord(), which are replaced at print time with the actual extents computed from the layout.

Usage

coord_chord(layout = NULL)

Arguments

layout

Chord layout object (passed internally by ggchord(), may be NULL)

Value

A Coord object for ggplot2 + composition

Examples

library(ggchord)
data(seq_data_example)
p <- ggchord(seq_data_example) + coord_chord() + geom_seq()
#> Coordinate system already present.
#>  Adding new coordinate system, which will replace the existing one.
p