R/ggchord.R
plus-.ggchord.Rd
Supports stacking ggplot2 layers, lists of layers, scales, and themes onto a ggchord plot using the + operator.
+
# S3 method for class 'ggchord' e1 + e2
A ggchord object
A ggplot2 layer, a list of layers, a scale, or a theme